@@ -190,7 +190,7 @@ class TmxPicoAio:
                           range(23)}
 
         # skip over unavailable pins
-        for pin in range(25, 29):
+        for pin in range(26, 29):
             self.pico_pins[pin] = PrivateConstants.AT_MODE_NOT_SET
 
         # creating a list of available sda and scl pins for i2c. If assigned the pins
@@ -696,7 +696,17 @@ class TmxPicoAio:
         """
         Set a pin as an analog input.
 
-        :param adc_number: ADC Number 0-3 - ADC 3 is the temp sensor
+        :param adc_number: ADC Number 0-4
+
+                           ADC numbers are mapped as following:
+                           ADC0 = GPIO 26 (Physical Pin 31)
+                           ADC1 = GPIO 27 (Physical Pin 32)
+                           ADC2 = GPIO 28 (Physical Pin 34)
+
+                           Internal Mapping
+                           ADC3 = GPIO 29 (Physical Pin 35) ADC Reference Voltage
+                           ADC4 = GPIO 30 (No Physical pin - mapped internally)
+                                          CPU temperature
 
         :param differential: difference in previous to current value before
                              report will be generated
@@ -712,7 +722,7 @@ class TmxPicoAio:
 
         """
         # make sure adc number is in range
-        if not 0 < adc_number < 5:
+        if not 0 <= adc_number < 5:
             raise RuntimeError('Invalid ADC Number')
         await self._set_pin_mode(adc_number, PrivateConstants.AT_ANALOG, differential,
                                  callback=callback)
